==> haskell-expiring-cache-map-0.0.6.1-361-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-expiring-cache-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 expiring-cache-map
version:              0.0.6.1
visibility:           public
id:                   expiring-cache-map-0.0.6.1-G6JcvdrvYV37OvKCLHp0aO
key:                  expiring-cache-map-0.0.6.1-G6JcvdrvYV37OvKCLHp0aO
license:              BSD-3-Clause
copyright:            (c) 2014 Edward L. Blake
maintainer:           edwardlblake@gmail.com
author:               Edward L. Blake
homepage:             https://github.com/elblake/expiring-cache-map
synopsis:             General purpose simple caching.
description:
    A simple general purpose shared state cache map with automatic expiration
    of values, for caching the results of accessing a resource such as reading
    a file. With variations for Ord and Hashable keys using "Data.Map.Strict"
    and "Data.HashMap.Strict", respectively.

category:             Caching
abi:                  a65f4dd0c694b884091f110e35076bb6
exposed:              True
exposed-modules:
    Caching.ExpiringCacheMap.HashECM
    Caching.ExpiringCacheMap.Internal.Internal
    Caching.ExpiringCacheMap.Internal.Types
    Caching.ExpiringCacheMap.OrdECM Caching.ExpiringCacheMap.Types
    Caching.ExpiringCacheMap.Utils.TestSequence
    Caching.ExpiringCacheMap.Utils.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/expiring-cache-map-0.0.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/expiring-cache-map-0.0.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/expiring-cache-map-0.0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-expiring-cache-map
hs-libraries:         HSexpiring-cache-map-0.0.6.1-G6JcvdrvYV37OvKCLHp0aO
depends:
    base-4.17.2.1 containers-0.6.7
    hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    unordered-containers-0.2.20-L3M6eILO3KM5ipeNJik2xY

haddock-interfaces:
    /usr/share/doc/haskell-expiring-cache-map/html/expiring-cache-map.haddock

haddock-html:         /usr/share/doc/haskell-expiring-cache-map/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-expiring-cache-map-0.0.6.1-368-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-expiring-cache-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 expiring-cache-map
version:              0.0.6.1
visibility:           public
id:                   expiring-cache-map-0.0.6.1-4HVf2mh1dGFHwHfkOKGBVI
key:                  expiring-cache-map-0.0.6.1-4HVf2mh1dGFHwHfkOKGBVI
license:              BSD-3-Clause
copyright:            (c) 2014 Edward L. Blake
maintainer:           edwardlblake@gmail.com
author:               Edward L. Blake
homepage:             https://github.com/elblake/expiring-cache-map
synopsis:             General purpose simple caching.
description:
    A simple general purpose shared state cache map with automatic expiration
    of values, for caching the results of accessing a resource such as reading
    a file. With variations for Ord and Hashable keys using "Data.Map.Strict"
    and "Data.HashMap.Strict", respectively.

category:             Caching
abi:                  088a9192db47953d58ea90c123db8cbe
exposed:              True
exposed-modules:
    Caching.ExpiringCacheMap.HashECM
    Caching.ExpiringCacheMap.Internal.Internal
    Caching.ExpiringCacheMap.Internal.Types
    Caching.ExpiringCacheMap.OrdECM Caching.ExpiringCacheMap.Types
    Caching.ExpiringCacheMap.Utils.TestSequence
    Caching.ExpiringCacheMap.Utils.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/expiring-cache-map-0.0.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/expiring-cache-map-0.0.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/expiring-cache-map-0.0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-expiring-cache-map
hs-libraries:         HSexpiring-cache-map-0.0.6.1-4HVf2mh1dGFHwHfkOKGBVI
depends:
    base-4.17.2.1 containers-0.6.7
    hashable-1.4.4.0-D3M5e9EeJxCJTqzfO7ugwa
    unordered-containers-0.2.20-Asw2mvs6LgrELNyeUEam3W

haddock-interfaces:
    /usr/share/doc/haskell-expiring-cache-map/html/expiring-cache-map.haddock

haddock-html:         /usr/share/doc/haskell-expiring-cache-map/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
